import React, { useEffect } from 'react';
import { View, StyleSheet, Platform } from 'react-native';
import { AMapSdk, MapView, Marker, MapType } from 'react-native-amap3d';
import { rpx } from '../../utils/rpx';

const MiniMap = () => {
  useEffect(() => {
    AMapSdk.init(
      Platform.select({
        android: "812efd3a950ba3675f928630302c6463",
      })
    );
  }, []);

  // Marker 的坐标
  const latitude = 26.95500669;
  const longitude = 120.32736769;
  const imageUrl = "https://lxnapi.ccttiot.com/bike/img/static/uRx1B8B8acbquF2TO7Ry";
  
  return (
    <View style={styles.container}>
      <MapView
        style={styles.map}
        mapType={MapType.Standard} // 测试使用标准地图
        zoomControlsEnabled={false} // 禁用加减缩放按钮
        initialCameraPosition={{
          target: {
            latitude,
            longitude,
          },
          zoom: 15,
        }}
      >
        {/* 添加 Marker */}
        <Marker
          position={{
            latitude,
            longitude,
          }}
          icon={{ uri: imageUrl }} // 设置 Marker 图标
        />
      </MapView>
    </View>
  );
};

// styles 保持不变
const styles = StyleSheet.create({
  container: {
    marginTop: rpx(44),
    width: rpx(688),
    height: rpx(380),
    borderRadius: rpx(20),
    overflow: 'hidden', // Ensure rounded corners are applied to the map
  },
  map: {
    width: '100%',
    height: '100%',
  },
});

export default MiniMap;
