import React, { useRef } from 'react';
import { View, Text, StyleSheet, Animated, Image } from 'react-native';
import { PanGestureHandler, State, GestureHandlerRootView, PanGestureHandlerGestureEvent } from 'react-native-gesture-handler';
import { rpx } from '../../utils/rpx'; // Adjust the path as necessary

const Slider: React.FC = () => {
    const translateX = useRef(new Animated.Value(0)).current;

    const bgColorInterpolate = translateX.interpolate({
        inputRange: [0, rpx(268)],
        outputRange: ['#EBEBEB', 'blue']
    });

    const opacityInterpolate = translateX.interpolate({
        inputRange: [0, rpx(268)],
        outputRange: [1, 0]
    });

    const onGestureEvent = Animated.event<PanGestureHandlerGestureEvent>(
        [{ nativeEvent: { translationX: translateX } }],
        { useNativeDriver: false }
    );

    const onHandlerStateChange = (event: any) => {
        if (event.nativeEvent.oldState === State.ACTIVE) {
            let toValue = 0;
            if (event.nativeEvent.translationX > rpx(268) / 2) {
                toValue = rpx(268);
            }

            Animated.spring(translateX, {
                toValue,
                useNativeDriver: false
            }).start();
        }
    };

    return (
        <GestureHandlerRootView style={{ flex: 1 }}>
            <View style={styles.container}>
                <View style={styles.car_Opne_box}>
                    <Animated.View
                        style={[
                            styles.car_Opne,
                            { backgroundColor: bgColorInterpolate }
                        ]}
                    >
                        <PanGestureHandler
                            onGestureEvent={onGestureEvent}
                            onHandlerStateChange={onHandlerStateChange}
                        >
                            <Animated.View style={{ 
                                transform: [{
                                    translateX: translateX.interpolate({
                                        inputRange: [0, rpx(268)],
                                        outputRange: [0, rpx(268)],
                                        extrapolate: 'clamp' // 限制滑动范围
                                    })
                                }]
                            }}>
                                <Animated.Image
                                    source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/uY9tYXXZztuE1VTLDl5y' }}
                                    style={[
                                        styles.image,
                                        { opacity: opacityInterpolate }
                                    ]}
                                />
                            </Animated.View>
                        </PanGestureHandler>
                        <Image
                            source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/uEJob4XbADaL9ohOTVTL' }}
                            style={{ width: rpx(32), height: rpx(32), marginLeft: 'auto' }}
                        />
                    </Animated.View>
                    <Text style={{ fontSize: rpx(32), color: '#3D3D3D', textAlign: 'center', marginTop: rpx(24) }}>右滑启动</Text>
                </View>
            </View>
        </GestureHandlerRootView>
    );
};

const styles = StyleSheet.create({
    container: {
        flex: 1,
        justifyContent: 'center',
        alignItems: 'center',
    },
    car_Opne_box: {
        justifyContent: 'center'
    },
    car_Opne: {
        width: rpx(268),
        height: rpx(90),
        flexDirection: 'row',
        backgroundColor: "#EBEBEB",
        alignItems: 'center',
        paddingRight: rpx(30),
        borderRadius: rpx(45)
    },
    image: {
        width: rpx(86),
        height: rpx(86)
    }
});

export default Slider;