import React, { useEffect, useState, useRef } from 'react';
import { View, Text, StyleSheet, Image, PanResponder, Animated, ScrollView, TouchableOpacity } from 'react-native';
import http from '../../utils/http'; // 调整路径
import { rpx } from '../../utils/rpx'; // Adjust the path as necessary
import Slider from "./slider";
import MiniMap from './MiniMap';
import { useNavigation } from '@react-navigation/native';
const NormaIndex: React.FC = () => {

    const [count, setCount] = useState(0);
    const [data, setData] = useState(null);
    const translateX = useRef(new Animated.Value(0)).current;
    const bgColor = useRef(new Animated.Value(0)).current;

    const navigation = useNavigation();

    const handlePress = () => {
        navigation.navigate('deviceList'); // 确保 'deviceList' 是正确的页面名称
    };
    const panResponder = useRef(
        PanResponder.create({
            onStartShouldSetPanResponder: () => true,
            onPanResponderMove: Animated.event(
                [null, { dx: translateX }],
                { useNativeDriver: false }
            ),
            onPanResponderRelease: (_, gestureState) => {
                if (gestureState.dx > rpx(268) / 2) {
                    Animated.parallel([
                        Animated.timing(translateX, {
                            toValue: rpx(268),
                            duration: 300,
                            useNativeDriver: false
                        }),
                        Animated.timing(bgColor, {
                            toValue: 1,
                            duration: 300,
                            useNativeDriver: false
                        })
                    ]).start();
                } else {
                    Animated.parallel([
                        Animated.timing(translateX, {
                            toValue: 0,
                            duration: 300,
                            useNativeDriver: false
                        }),
                        Animated.timing(bgColor, {
                            toValue: 0,
                            duration: 300,
                            useNativeDriver: false
                        })
                    ]).start();
                }
            }
        })
    ).current;

    const bgColorInterpolate = bgColor.interpolate({
        inputRange: [0, 1],
        outputRange: ['#EBEBEB', 'blue']
    });

    const opacityInterpolate = translateX.interpolate({
        inputRange: [0, rpx(268)],
        outputRange: [1, 0]
    });

    useEffect(() => {
        // 发起 GET 请求
        http.get('/app/article/9') // 替换为你的 API endpoint
            .then(response => {
                // setData(response); // Uncomment when API response is needed
            })
            .catch(error => {
                console.error('请求错误', error);
            });
    }, []);

    return (
        <ScrollView contentContainerStyle={styles.scrollContent}>
            <View style={styles.container}>
                <View style={styles.titBox}>
                    <Text style={styles.titTxt}>朵VFLU-13762</Text>
                </View>
                <View style={styles.KmBox}>
                    <View style={styles.KmLi}>
                        <View style={styles.KmLi_top}>
                            <Text style={styles.titTxt}>110</Text>
                            <Text style={styles.KmLi_tits}>km</Text>
                        </View>
                        <View style={styles.KmLi_bot}>
                            <Image source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/uDg93bCzlPFiFBtS71Al' }}
                                style={{ width: rpx(32), height: rpx(32) }} />
                            <Text style={styles.KmLi_tits1}>剩余里程</Text>
                        </View>
                    </View>
                    <View style={styles.KmLi}>
                        <View style={styles.KmLi_top}>
                            <Text style={styles.titTxt}>110</Text>
                            <Text style={styles.KmLi_tits}>km</Text>
                        </View>
                        <View style={styles.KmLi_bot}>
                            <Image source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/uDg93bCzlPFiFBtS71Al' }}
                                style={{ width: rpx(32), height: rpx(32) }} />
                            <Text style={styles.KmLi_tits1}>剩余里程</Text>
                        </View>
                    </View>
                </View>
                <View style={styles.infoBox}>
                    <View style={styles.eleBox}>
                        <View style={styles.eleType}>
                            <Text style={styles.eleTypeTxt}>90%</Text>
                        </View>
                    </View>
                    <View style={styles.carBox}>
                        <Image source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/uVnIDwcwQP7oo12PeYVJ' }}
                            style={{ width: rpx(440), height: rpx(340) }} />
                        <View style={styles.txtbox}>
                            <View style={styles.yuan}></View>
                            <Text style={styles.txt}>当前车辆状态：锁车</Text>
                        </View>
                    </View>
                    <View style={styles.Bind_type}>
                        <Image source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/uQdjlI2DLfXmABfynycn' }}
                            style={{ width: rpx(32), height: rpx(32) }} />
                        <Image source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/uLizPj6UxdjBsiqhxZB8' }}
                            style={{ width: rpx(60), height: rpx(60), marginLeft: 'auto' }} />
                    </View>
                </View>
                <View style={styles.car_stause_box}>
                    <View style={styles.car_stause_li}>
                        <Image source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/uro1vIU1WydjNWgi7PUg' }}
                            style={{ width: rpx(90), height: rpx(90), marginLeft: rpx(18) }} />
                        <Text style={{ fontSize: rpx(32), color: '#3D3D3D', textAlign: 'center', marginTop: rpx(24) }}>鸣笛寻车</Text>
                    </View>
                    <Slider />
                    <View style={styles.car_stause_li}>
                        <Image source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/uVpJNxwWXlyXt4IdHQoe' }}
                            style={{ width: rpx(90), height: rpx(90), marginLeft: rpx(18) }} />
                        <Text style={{ fontSize: rpx(32), color: '#3D3D3D', textAlign: 'center', marginTop: rpx(24) }}>警报已开</Text>
                    </View>
                </View>
                <MiniMap />
                {/* <TouchableOpacity onPress={handlePress}>
                    <Image
                        source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/ucYQHQ2Ep4odL8JpbtfT' }}
                        style={styles.otherSet}
                    />
                </TouchableOpacity> */}
                 <Image
                        source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/ucYQHQ2Ep4odL8JpbtfT' }}
                        style={styles.otherSet}
                    />
                <View style={styles.otherSet}>
                    <Image source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/ulDHhC4MrH3FO0AeTqVg' }} style={styles.otherImg} />
                    <Image source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/u849NsNxdtzxhUkUJnfW' }} style={styles.otherImg} />
                </View>
            </View>
        </ScrollView>
    );
};
const styles = StyleSheet.create({
    scrollContent: {
        flexGrow: 1, // This ensures the content expands to fill the available space
    },
    otherSet: {
        marginTop: rpx(30),
        // display:f,\
        flexDirection: 'row', // 保持在一行中
        justifyContent: 'space-between'

    },
    otherImg: {
        width: rpx(328),
        height: rpx(160),
    },
    carSet: {
        marginTop: rpx(30),
        width: rpx(688),
        height: rpx(380),
    },
    car_Opne_box: {
        justifyContent: 'center'
    },
    MiniMap: {
        // marginTop:rpx(44),
        marginBottom: rpx(44),
    },
    car_Opne: {
        width: rpx(268),
        height: rpx(90),
        flexDirection: 'row', // 保持在一行中
        backgroundColor: "#EBEBEB",
        alignItems: 'center',
        paddingRight: rpx(30),
        borderRadius: rpx(45)
    },
    car_stause_li: {
        width: rpx(136),
        justifyContent: 'center'
    },
    car_stause_box: {
        marginTop: rpx(308),
        flexDirection: 'row', // 保持在一行中
        justifyContent: 'space-around'
    },
    infoBox: {

        marginTop: rpx(66),
        flexDirection: 'row', // 保持在一行中
        // alignItems:'center',
        justifyContent: 'space-between'
    },
    carBox: {
        width: rpx(440),
        position: 'absolute',

        top: rpx(20),
        left: rpx(124),
        zIndex: 0,
    },
    Bind_type: {
        flexDirection: 'row', // 保持在一行中

        width: rpx(272),
        height: rpx(60),
        backgroundColor: '#fff',
        borderRadius: rpx(30),
        alignItems: 'center',
    },
    txtbox: {
        width: rpx(440),
        justifyContent: 'center',
        flexDirection: 'row', // 保持在一行中
        alignItems: 'center', // 垂直居中对齐
    },
    txt: {
        marginLeft: rpx(14), // 为了给圆形和文本之间留出一些间距
        fontSize: rpx(28),
        fontWeight: '400',
        color: '#3D3D3D',
    },
    yuan: {
        width: rpx(22),
        height: rpx(22),
        borderRadius: rpx(11),
        backgroundColor: 'rgba(255, 130, 130, 1)',
    },
    eleTypeTxt: {
        position: 'absolute',
        top: rpx(16),
        left: rpx(6),
        fontSize: rpx(32),
        color: '#3D3D3D',
        fontWeight: 'bold'
    },
    eleBox: {
        paddingTop: rpx(14),
        paddingRight: rpx(6),
        paddingBottom: rpx(6),
        paddingLeft: rpx(6),
        width: rpx(86),
        height: rpx(166),
        borderRadius: rpx(16),
        backgroundColor: '#fff'
    },
    eleType: {
        width: '100%',
        height: '100%',
        borderRadius: rpx(16),
        backgroundColor: 'rgba(89,202,112,0.5)'
    },
    titBox: {

    },

    KmLi_bot: {
        marginTop: rpx(4),
        flexDirection: 'row', // 保持在一行中
        alignItems: 'center', // 垂直居中对齐
    },
    KmLi_tits1: {
        marginLeft: rpx(4),
        fontSize: rpx(28),
        color: '#808080',
    },
    container: {
        flex: 1, // Ensure this takes full height of screen
        // width: '100%',
        // height: '100%',

        backgroundColor: '#F3FCFF',
        padding: rpx(32),
        // paddingBottom:rpx(500),
    },
    KmBox: {
        marginTop: rpx(28),
        width: '100%',

        flexDirection: 'row', // 保持在一行中
        alignItems: 'center', // 垂直居中对齐
        justifyContent: 'space-between',
    },
    KmLi: {
        // width: '50%',

    },

    KmLi_tits: {
        paddingBottom: rpx(10),
        fontSize: rpx(24),
        color: '#3D3D3D',
        // fontWeight:'bold'
    },
    KmLi_top: {
        width: '100%',

        flexDirection: 'row',
        flexWrap: 'nowrap',
        verticalAlign: 'bottom',
        alignItems: "flex-end",
    },

    titTxt: {
        fontSize: rpx(48),
        color: '#3D3D3D',
        fontWeight: 'bold'
    }

});


export default NormaIndex;
